@@ -240,7 +240,7 @@ def vect_to_color(vect,style='hot'):
     cmap = LinearSegmentedColormap.from_list("WhRd", ((1,1,1),(1,0,0)), N=256)
     return(cmap(vect))
 
-def draw_plot(plot,exemplars,color_vect, colorize_by_gene = None):
+def draw_plot(plot,exemplars,color_vect, subset, colorize_by_gene = None):
     global all_group_ids, plt, full_expression, ID_list, ID_hash
     plt.clf()
 
@@ -254,6 +254,7 @@ def draw_plot(plot,exemplars,color_vect, colorize_by_gene = None):
         else:
             colorize_by_gene = str(float(colorize_by_gene))
         expression_vect = full_expression[ID_hash[colorize_by_gene],:]
+        expression_vect = expression_vect[subset]
         expression_vect = rankdata(expression_vect,method='min')
         colorized_vect = vect_to_color(expression_vect,style='Reds')
 
@@ -371,7 +372,8 @@ else:
 ID_list = row_names[:]
 ID_hash = {name:idx for idx,name  in enumerate(ID_list)}
 
-
+col_names = title[1:]
+col_hash = {name:idx for idx, name in enumerate(col_names)}
 ############################################
 
 
@@ -404,6 +406,28 @@ args.out_dir = process_dir(args.out_dir)
 group_reordering_vector=np.array(cluster_result_dict['group_reordering_vector'])
 reordered_colors=np.array(cluster_result_dict['reordered_colors'])
 
+sample_indices_for_plotting = cluster_result_dict['sample_indices_for_plotting']
+sample_indices_for_plotting_set = set(sample_indices_for_plotting)
+
+#######
+## filter some vars for the subset
+#print(reordered_groups)
+cluster_lists = []
+for i in range(len(sample_k_lists)):
+    cluster_lists.append([])
+    for j in range(len(sample_k_lists[i])):
+        #print(sample_k_lists[i][j])
+        if col_hash[sample_k_lists[i][j]] in sample_indices_for_plotting_set:
+            cluster_lists[i].append(sample_k_lists[i][j])
+    #print(cluster_lists[i])
+
+group_reordering_vector_subset = []
+reordered_colors_subset = []
+for i in range(len(group_reordering_vector)):
+    if group_reordering_vector[i] in sample_indices_for_plotting_set:
+        reordered_colors_subset.append(reordered_colors[i])
+        group_reordering_vector_subset.append(group_reordering_vector[i])
+
 
 #######################################################
 ## get the column labels
@@ -418,9 +442,6 @@ for i in range(1,len(reordered_array)):
 	if int(reordered_array[i])!=int(reordered_groups[-1]):
 		reordered_groups.append(reordered_array[i])
 
-#print(reordered_groups)
-
-cluster_lists = sample_k_lists[:]
 temp_label_lists = []
 for i in range(0,len(cluster_lists)):
 	temp_list = ['']*len(cluster_lists[i])
@@ -428,8 +449,8 @@ for i in range(0,len(cluster_lists)):
 	temp_label_lists.append(temp_list)
 
 heatmap_x_labels = []
-for i in reordered_groups:
-	heatmap_x_labels+=temp_label_lists[i]
+for i in range(len(temp_label_lists)):
+    heatmap_x_labels+=temp_label_lists[i]
 #print(heatmap_x_labels)
 
 #######################################################
@@ -471,10 +492,11 @@ subset_indices = np.array(subset_indices)
 print(subset_indices)
 if np.shape(subset_indices)[0]==0:
     sys.exit('no subset found...')
-subset_array = np.zeros((subset_indices.shape[0],full_expression.shape[1]))
+## create the subset array
+subset_array = np.zeros((subset_indices.shape[0],len(sample_indices_for_plotting)))
 for i in range(subset_indices.shape[0]):
     temp_idx = subset_indices[i]
-    subset_array[i,:] = np.array(full_expression[temp_idx,:])
+    subset_array[i,:] = np.array(full_expression[temp_idx,np.array(sample_indices_for_plotting)])
 
 
 # if not args.cluster:
@@ -482,7 +504,15 @@ for i in range(subset_indices.shape[0]):
 #     subset_array=subset_array[original_order_rank,:]
 #     subset_sorted_names = subset_sorted_names[original_order_rank]
 
+
+#subset_ID_hash = {}
+
+
 ## do the linear normalization
+#temp_idxs = [idx for idx in ids_to_idxs(sample_k_lists[i]) if idx in set(sample_indices_for_plotting)]
+sample_for_plotting_idx_hash = {value:key for key, value in enumerate(sample_indices_for_plotting)}
+#temp_idxs = [sample_for_plotting_idx_hash[idx] for idx in temp_idxs]
+group_reordering_vector = [sample_for_plotting_idx_hash[idx] for idx in group_reordering_vector if idx in sample_for_plotting_idx_hash ]
 subset_array = lin_norm_rows(subset_array[:,group_reordering_vector])
 
 ## Z-score
@@ -559,7 +589,7 @@ try:
     sub = sns.clustermap(subset_df,
         col_cluster = False,
         row_cluster = row_cluster,
-        col_colors = reordered_colors,
+        col_colors = reordered_colors_subset,
         yticklabels = True,
         #xticklabels=xticklabels,
         cmap=global_cmap)
@@ -572,7 +602,7 @@ except:
     sub = sns.clustermap(np.array(subset_df)[sub_sample,:],
         col_cluster = False,
         row_cluster = row_cluster,
-        col_colors = reordered_colors,
+        col_colors = reordered_colors_subset,
         yticklabels = True,
         #xticklabels=xticklabels,
         cmap=global_cmap)
@@ -607,7 +637,7 @@ for noi in nodes_of_interest:
         # for k in [plot].keys():
         #     print(k)
         #     print(plot[k])
-        draw_plot(cluster_result_dict["plots"][plot],cluster_result_dict["exemplar_indices"],cluster_result_dict["color_vect"],colorize_by_gene = noi)
+        draw_plot(cluster_result_dict["plots"][plot],cluster_result_dict["exemplar_indices"],cluster_result_dict["color_vect"], np.array(sample_indices_for_plotting), colorize_by_gene = noi)
         temp_plot_out = plot.split('/')
         temp_plot_out = temp_plot_out[-1]
         plt.savefig(args.out_dir+temp_plot_out[:-4]+'_'+alias_dict[noi]+'.png',
