@@ -586,7 +586,7 @@ def main(args):
         plot_subset_call += " -cluster_pkl "+temp+"/sample_clustering_and_summary/clustering_plots.pkl"
         if args.h5py:
             plot_subset_call += ' -hdf5 '
-            plot_subset_call += ' -cols '+temp+'/column_IDs.txt'
+            plot_subset_call += ' -cols '+os.path.join(temp,args.columns)
         all_calls.append(plot_subset_call)
         cmd(plot_subset_call)
 
