@@ -6,8 +6,14 @@ import math
 from collections import namedtuple
 
 # Scipy imports.
-from scipy._lib.six import callable, string_types, xrange
-from scipy._lib._version import NumpyVersion
+try:
+    from scipy._lib.six import callable, string_types, xrange
+except:
+    pass
+try:
+    from scipy._lib._version import NumpyVersion
+except:
+    pass
 from numpy import array, asarray, ma, zeros, var, average
 import multiprocessing
 from multiprocessing.dummy import Pool as ThreadPool
